@@ -527,7 +527,7 @@ vvm_preferences_refresh_settings (void)
 
   if (vvm_settings_get_service_available (settings))
     {
-      if (vvmplayer_vvmd_get_service_settings (backend) == FALSE)
+      if (vvmplayer_vvmd_update_service_settings (backend) == FALSE)
         {
           g_debug ("Error getting VVMD Service Settings");
           vvm_settings_load_service_defaults (settings);
@@ -545,11 +545,26 @@ vvm_player_preferences_window_new (void)
   return g_object_new (ADW_TYPE_DEMO_PREFERENCES_WINDOW, NULL);
 }
 
+static void
+vvm_player_preferences_window_finalize (GObject *object)
+{
+  VvmplayerPreferencesWindow *self = (VvmplayerPreferencesWindow *)object;
+  VvmVvmd *backend = vvm_vvmd_get_default ();
+
+  g_signal_handler_disconnect (backend,
+                               self->vvm_settings_watch_id);
+
+  G_OBJECT_CLASS (vvm_player_preferences_window_parent_class)->finalize (object);
+}
+
 static void
 vvm_player_preferences_window_class_init (VvmplayerPreferencesWindowClass *klass)
 {
+  GObjectClass   *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
+  object_class->finalize = vvm_player_preferences_window_finalize;
+
   gtk_widget_class_set_template_from_resource (widget_class, "/org/kop316/vvmplayer/ui/vvmplayer-preferences-window.ui");
 
   //Refresh Page
